==> vice_1.20.orig.tar.gz: vice-1.20/src/pet/petreu.h <==
/*
 * petreu.h - PET Ram and Expansion Unit emulation.
 *
 * Written by
 *  Marco van den Heuvel <blackystardust68@yahoo.com>
 *
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */

#ifndef _PET_REU_H
#define _PET_REU_H

#include "types.h"

extern int petreu_enabled;

extern int petreu_resources_init(void);
extern void petreu_resources_shutdown(void);
extern int petreu_cmdline_options_init(void);
extern void petreu_init(void);
extern void petreu_reset(void);
extern void petreu_shutdown(void);
extern BYTE REGPARM1 read_petreu_reg(WORD addr);
extern BYTE REGPARM1 read_petreu_ram(WORD addr);
extern void REGPARM2 store_petreu_reg(WORD addr, BYTE byte);
extern void REGPARM2 store_petreu_ram(WORD addr, BYTE byte);

#endif

==> vice_1.22.dfsg1.orig.tar.gz: vice-1.22/src/pet/petreu.h <==
/*
 * petreu.h - PET Ram and Expansion Unit emulation.
 *
 * Written by
 *  Marco van den Heuvel <blackystardust68@yahoo.com>
 *
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */

#ifndef _PET_REU_H
#define _PET_REU_H

#include "types.h"

extern int petreu_enabled;

extern int petreu_resources_init(void);
extern void petreu_resources_shutdown(void);
extern int petreu_cmdline_options_init(void);
extern void petreu_init(void);
extern void petreu_reset(void);
extern void petreu_shutdown(void);
extern BYTE REGPARM1 read_petreu_reg(WORD addr);
extern BYTE REGPARM1 read_petreu2_reg(WORD addr);
extern BYTE REGPARM1 read_petreu_ram(WORD addr);
extern void REGPARM2 store_petreu_reg(WORD addr, BYTE byte);
extern void REGPARM2 store_petreu2_reg(WORD addr, BYTE byte);
extern void REGPARM2 store_petreu_ram(WORD addr, BYTE byte);

#endif
